Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Collector ¶
The Collector is informed of any new requests coming in and of replication attempt, it stores these values and exposes stats of a shadowing run.
type Config ¶
type Config struct {
// contains filtered or unexported fields
}
Config contains the internal configuration for a worker
Click to show internal directories.
Click to hide internal directories.