Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
// contains filtered or unexported fields
}
The Config struct contains the internal configuration for a Pool
func (*Config) Add ¶
Add pushes an item of work to the pool n times, returns the number of items of work that were succeesfully pushed. The returned number may be less than n when the work channel buffer is full.
Click to show internal directories.
Click to hide internal directories.